@@ -8,10 +8,10 @@ module Config.Dyre.Params ( Params(..), RTSOptionHandling(..) ) where
 -- | This structure is how all kinds of useful data is fed into Dyre. Of
 --   course, only the 'projectName', 'realMain', and 'showError' fields
 --   are really necessary. By using the set of default values provided
---   as 'Config.Dyre.defaultParams', you can get all the benefits of
+--   as 'Config.Dyre.newParams', you can get all the benefits of
 --   using Dyre to configure your program in only five or six lines of
 --   code.
-data Params cfgType = Params
+data Params cfgType a = Params
     { projectName  :: String
     -- ^ The name of the project. This needs to also be the name of
     --   the executable, and the name of the configuration file.
@@ -24,7 +24,7 @@ data Params cfgType = Params
     , cacheDir     :: Maybe (IO FilePath)
     -- ^ The directory to store build files in, including the final
     --   generated executable.
-    , realMain     :: cfgType -> IO ()
+    , realMain     :: cfgType -> IO a
     -- ^ The main function of the program. When Dyre has completed
     --   all of its recompilation, it passes the configuration data
     --   to this function and gets out of the way.
@@ -32,6 +32,10 @@ data Params cfgType = Params
     -- ^ This function is used to display error messages that occur
     --   during recompilation, by allowing the program to modify its
     --   initial configuration.
+    , includeDirs  :: [FilePath]
+    -- ^ Optional extra include dirs to use during compilation.
+    --   To support installation via cabal-install, include the
+    --   path returned from @Paths_\<appName\>.getLibDir@.
     , hidePackages :: [String]
     -- ^ Packages that need to be hidden during compilation
     , ghcOpts      :: [String]
@@ -51,6 +55,11 @@ data Params cfgType = Params
     --   prevent name shadowing within project directory.)  --
     }
 
-data RTSOptionHandling = RTSReplace [String] -- replaces RTS options with given list
-                       | RTSAppend  [String] -- merges given list with RTS options from command line (so that nothing is lost)
+
+-- | Specify additional or replacement GHC runtime system options
+data RTSOptionHandling
+  = RTSReplace [String]
+  -- ^ replaces RTS options with given list
+  | RTSAppend  [String]
+  -- ^ merges given list with RTS options from command line (so that nothing is lost)
 
