@@ -1,2 +1,2 @@
-import BasicTest
+import Lib
 main = basicTest $ defaultConfig { message = "Basic Test Version 2.0" }
